pub struct DensityFieldSpatialObject {
pub body_entity: Entity,
pub aabb: Aabb<Scalar>,
pub collision_profile: CollisionProfile,
}Fields
body_entity: Entityaabb: Aabb<Scalar>collision_profile: CollisionProfileTrait Implementations
Sourceimpl PointDistance for DensityFieldSpatialObject
impl PointDistance for DensityFieldSpatialObject
Sourcefn distance_2(
&self,
point: &<Self::Envelope as Envelope>::Point,
) -> <<Self::Envelope as Envelope>::Point as Point>::Scalar
fn distance_2( &self, point: &<Self::Envelope as Envelope>::Point, ) -> <<Self::Envelope as Envelope>::Point as Point>::Scalar
Returns the squared distance between an object and a point. Read more
Sourcefn contains_point(&self, point: &<Self::Envelope as Envelope>::Point) -> bool
fn contains_point(&self, point: &<Self::Envelope as Envelope>::Point) -> bool
Returns
true if a point is contained within this object. Read moreSourcefn distance_2_if_less_or_equal(
&self,
point: &<Self::Envelope as Envelope>::Point,
max_distance_2: <<Self::Envelope as Envelope>::Point as Point>::Scalar,
) -> Option<<<Self::Envelope as Envelope>::Point as Point>::Scalar>
fn distance_2_if_less_or_equal( &self, point: &<Self::Envelope as Envelope>::Point, max_distance_2: <<Self::Envelope as Envelope>::Point as Point>::Scalar, ) -> Option<<<Self::Envelope as Envelope>::Point as Point>::Scalar>
Returns the squared distance to this object, or
None if the distance
is larger than a given maximum value. Read moreAuto Trait Implementations
impl Freeze for DensityFieldSpatialObject
impl RefUnwindSafe for DensityFieldSpatialObject
impl Send for DensityFieldSpatialObject
impl Sync for DensityFieldSpatialObject
impl Unpin for DensityFieldSpatialObject
impl UnsafeUnpin for DensityFieldSpatialObject
impl UnwindSafe for DensityFieldSpatialObject